Contact - ITOM Library

# Contact Us

Get in touch with the ITOM Library team for support, collaboration, or questions.

## Send a Message

First Name
Last Name
Email Address
Company (Optional)
Subject
Message
I agree to the privacy policy and terms of service

## Connect With Us

##### Quick Links

- GitLab Repository
- padith@opentext.com
- Documentation
- Website

## Response Time

General Inquiries: 24-48 hours

Technical Support: 1-2 business days

Enterprise: Priority support available

## Support Resources

###### Documentation

Complete guides & API reference

###### FAQ

Common questions answered

###### Video Tutorials

Learn with step-by-step videos

## Location

##### Bangalore

Olympia, Bagmane Tech Park

Bangalore, Karnataka, 560093

India